@@ -10,17 +10,21 @@ class Distro(Module):
         )
 
 
-class FreeBSD(Distro):
+class FreeBSD_13(Distro):
     def do_deploy(self, target, **kw):
         return self.install(target,
-            pkg = 'sudo bash python',
+            pkg = 'sudo bash python rust',
         )
 
 
 class Fedora(Distro):
     def do_deploy(self, target, **kw):
         ok = self.install(target,
-            pkg = 'langpacks-fr',
+            pkg = '''
+                langpacks-fr
+                langpacks-en
+                glibc-all-langpacks
+            ''',
         )
         if ok:
             ret, out, err = self.run('localectl set-locale LANG=fr_FR.UTF-8')
