@@ -31,6 +31,6 @@ class Distro(Module):
 
         ok = 'wheel' in grp.get()
         ret, out, err = target.run(f'sudo -l -U {user}')
-        ok = ok and '(ALL) NOPASSWD: ALL' == out[-1].strip()
+        ok = ok and '(ALL) NOPASSWD: ALL' in (line.strip() for line in out)
 
         return ok
